@@ -45,7 +45,6 @@ import os
 import signal
 import subprocess
 import time
-from typing import Dict, List
 from urllib.parse import quote
 
 import univention.debug as ud  # pylint: disable-msg=E0611
@@ -139,7 +138,7 @@ def _quote_config_parameter(arg: str) -> str:
     return arg.replace('\\', '\\\\').replace('"', '\\"')
 
 
-def handler(dn: str, new: Dict[str, List[bytes]], old: Dict[str, List[bytes]]) -> None:
+def handler(dn: str, new: dict[str, list[bytes]], old: dict[str, list[bytes]]) -> None:
     """Handle LDAP changes."""
     base = listener.configRegistry.get('dns/ldap/base')
     if base and not dn.endswith(base):
@@ -169,7 +168,7 @@ def handler(dn: str, new: Dict[str, List[bytes]], old: Dict[str, List[bytes]]) -
         listener.unsetuid()
 
 
-def _ldap_auth_string(ucr: Dict[str, str]) -> str:
+def _ldap_auth_string(ucr: dict[str, str]) -> str:
     """Build extended LDAP query URI part containing bind credentials."""
     account = ucr.get('bind/binddn', ucr['ldap/hostdn'])
 
@@ -178,7 +177,7 @@ def _ldap_auth_string(ucr: Dict[str, str]) -> str:
         return '????!bindname=%s,!x-bindpw=%s,x-tls' % (quote(account), quote(fd.readline().rstrip()))
 
 
-def _new_zone(ucr: Dict[str, str], zonename: str, dn: str) -> None:
+def _new_zone(ucr: dict[str, str], zonename: str, dn: str) -> None:
     """Handle addition of zone."""
     ud.debug(ud.LISTENER, ud.INFO, 'DNS: Creating zone %s' % (zonename,))
     if not os.path.exists(NAMED_CONF_DIR):
@@ -260,7 +259,7 @@ def clean() -> None:
         listener.unsetuid()
 
 
-def _reload(zones: List[str], restart: bool = False, dns_backend: str = 'ldap') -> Dict[int, List[str]]:
+def _reload(zones: list[str], restart: bool = False, dns_backend: str = 'ldap') -> dict[int, list[str]]:
     """Force reload of zones; might restart daemon; returns pids."""
     pids = {}
     # Try to only reload the zones if rndc is available
@@ -285,13 +284,13 @@ def _reload(zones: List[str], restart: bool = False, dns_backend: str = 'ldap')
     # Fall back to restart, which will temporarily interrupt the service
     if restart:
         ud.debug(ud.LISTENER, ud.INFO, 'DNS: Restarting BIND')
-        cmd = ['service', 'bind9', 'restart']
+        cmd = ['service', 'named', 'restart']
         pid = os.spawnv(os.P_NOWAIT, '/usr/sbin/service', cmd)  # noqa: S606
         pids[pid] = cmd
     return pids
 
 
-def _wait_children(pids: Dict[int, List[str]], timeout: float = 15) -> None:
+def _wait_children(pids: dict[int, list[str]], timeout: float = 15) -> None:
     """Wait for child termination."""
     # Wait max 15 seconds for forked children
     timeout += time.time()
@@ -325,7 +324,7 @@ def _wait_children(pids: Dict[int, List[str]], timeout: float = 15) -> None:
         time.sleep(1)
 
 
-def _kill_children(pids: Dict[int, List[str]], timeout: float = 5) -> None:
+def _kill_children(pids: dict[int, list[str]], timeout: float = 5) -> None:
     """Kill children."""
     for pid in pids:
         try:
@@ -384,7 +383,7 @@ def postrun() -> None:
             for filename in os.listdir(PROXY_CACHE_DIR):
                 os.remove(os.path.join(PROXY_CACHE_DIR, filename))
                 if not os.path.exists(os.path.join(NAMED_CACHE_DIR, filename)):
-                    ud.debug(ud.LISTENER, ud.PROCESS, 'DNS: %s does not exist. Triggering a bind9 restart.' % (os.path.join(NAMED_CACHE_DIR, filename)))
+                    ud.debug(ud.LISTENER, ud.PROCESS, 'DNS: %s does not exist. Triggering a named restart.' % (os.path.join(NAMED_CACHE_DIR, filename)))
                     restart = True
                 elif filename.endswith('.zone'):
                     zone = filename[:-len('.zone')]
